@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-From PopupBubble.PopupTk import poptk
+from PopupBubble.PopupTk import poptk
 import argparse
 
 parser = argparse.ArgumentParser(description="Popup notification on the commandline")
